@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -34,7 +34,7 @@ class ContactPrintThemePreview : public GrantleeThemeEditor::PreviewWidget
 {
     Q_OBJECT
 public:
-    explicit ContactPrintThemePreview(const QString &projectDirectory, QWidget *parent = Q_NULLPTR);
+    explicit ContactPrintThemePreview(const QString &projectDirectory, QWidget *parent = nullptr);
     ~ContactPrintThemePreview();
 
     void updateViewer() Q_DECL_OVERRIDE;
