@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,7 +27,7 @@ class ThemeTemplateListWidget : public PimCommon::TemplateListWidget
 {
     Q_OBJECT
 public:
-    explicit ThemeTemplateListWidget(const QString &configName, QWidget *parent = Q_NULLPTR);
+    explicit ThemeTemplateListWidget(const QString &configName, QWidget *parent = nullptr);
     ~ThemeTemplateListWidget();
 
     QVector<PimCommon::defaultTemplate> defaultTemplates() Q_DECL_OVERRIDE;
@@ -37,7 +37,7 @@ class ThemeTemplateWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit ThemeTemplateWidget(const QString &title, QWidget *parent = Q_NULLPTR);
+    explicit ThemeTemplateWidget(const QString &title, QWidget *parent = nullptr);
     ~ThemeTemplateWidget();
 
 Q_SIGNALS:
